@@ -43,7 +43,7 @@
 
 EGG_SECURE_DECLARE (ssh_agent);
 
-typedef gboolean (*GkdSshAgentOperation) (GkdSshAgentService *agent, EggBuffer *req, EggBuffer *resp, GCancellable *cancellable, GError **error);
+typedef gboolean (*GkdSshAgentOperation) (GkdSshAgentService *agent, GSocketConnection *connection, EggBuffer *req, EggBuffer *resp, GCancellable *cancellable, GError **error);
 static const GkdSshAgentOperation operations[GKD_SSH_OP_MAX];
 
 enum {
@@ -159,16 +159,18 @@ gkd_ssh_agent_service_class_init (GkdSshAgentServiceClass *klass)
 
 static gboolean
 relay_request (GkdSshAgentService *self,
+	       GSocketConnection *connection,
 	       EggBuffer *req,
 	       EggBuffer *resp,
 	       GCancellable *cancellable,
 	       GError **error)
 {
-	return gkd_ssh_agent_process_call (self->process, req, resp, cancellable, error);
+	return _gkd_ssh_agent_call (connection, req, resp, cancellable, error);
 }
 
 static gboolean
 handle_request (GkdSshAgentService *self,
+		GSocketConnection *connection,
 		EggBuffer *req,
 		EggBuffer *resp,
 		GCancellable *cancellable,
@@ -187,7 +189,7 @@ handle_request (GkdSshAgentService *self,
 	else
 		func = relay_request;
 
-	return func (self, req, resp, cancellable, error);
+	return func (self, connection, req, resp, cancellable, error);
 }
 
 static void
@@ -228,6 +230,7 @@ ensure_key (GkdSshAgentService *self,
 	const gchar *label;
 	GHashTable *fields;
 	GTlsInteraction *interaction;
+	gchar *standard_error;
 
 	gchar *argv[] = {
 		SSH_ADD,
@@ -245,7 +248,6 @@ ensure_key (GkdSshAgentService *self,
 	argv[1] = info->filename;
 
 	fields = g_hash_table_new (g_str_hash, g_str_equal);
-	g_hash_table_insert (fields, "xdg:schema", "org.freedesktop.Secret.Generic");
 	unique = g_strdup_printf ("ssh-store:%s", info->filename);
 	g_hash_table_insert (fields, "unique", unique);
 
@@ -256,14 +258,15 @@ ensure_key (GkdSshAgentService *self,
 	g_object_unref (interaction);
 
 	if (!g_spawn_sync (NULL, argv, NULL,
-			   G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
+			   G_SPAWN_STDOUT_TO_DEV_NULL,
 	                   gcr_ssh_askpass_child_setup, askpass,
-	                   NULL, NULL, &status, &error)) {
+	                   NULL, &standard_error, &status, &error)) {
 		g_warning ("couldn't run %s: %s", argv[0], error->message);
 		g_error_free (error);
 	} else if (!g_spawn_check_exit_status (status, &error)) {
 		g_message ("the %s command failed: %s", argv[0], error->message);
-		g_error_free (error);
+		g_printerr ("%s", _gkd_ssh_agent_canon_error (standard_error));
+		g_free (standard_error);
 	} else {
 		add_key (self, key);
 	}
@@ -284,13 +287,15 @@ on_run (GThreadedSocketService *service,
 	EggBuffer req;
 	EggBuffer resp;
 	GError *error;
+	GSocketConnection *agent_connection;
 	gboolean ret;
 
 	egg_buffer_init_full (&req, 128, egg_secure_realloc);
 	egg_buffer_init_full (&resp, 128, (EggBufferAllocator)g_realloc);
 
 	error = NULL;
-	if (!gkd_ssh_agent_process_connect (self->process, self->cancellable, &error)) {
+	agent_connection = gkd_ssh_agent_process_connect (self->process, self->cancellable, &error);
+	if (!agent_connection) {
 		g_warning ("couldn't connect to ssh-agent: %s", error->message);
 		g_error_free (error);
 		goto out;
@@ -300,7 +305,8 @@ on_run (GThreadedSocketService *service,
 		/* Read in the request */
 		error = NULL;
 		if (!_gkd_ssh_agent_read_packet (connection, &req, self->cancellable, &error)) {
-			if (error->code != G_IO_ERROR_CANCELLED)
+			if (error->code != G_IO_ERROR_CANCELLED &&
+			    error->code != G_IO_ERROR_CONNECTION_CLOSED)
 				g_message ("couldn't read from client: %s", error->message);
 			g_error_free (error);
 			break;
@@ -308,7 +314,7 @@ on_run (GThreadedSocketService *service,
 
 		/* Handle the request */
 		error = NULL;
-		while (!(ret = handle_request (self, &req, &resp, self->cancellable, &error))) {
+		while (!(ret = handle_request (self, agent_connection, &req, &resp, self->cancellable, &error))) {
 			if (gkd_ssh_agent_process_get_pid (self->process) != 0) {
 				if (error->code != G_IO_ERROR_CANCELLED)
 					g_message ("couldn't handle client request: %s", error->message);
@@ -317,8 +323,10 @@ on_run (GThreadedSocketService *service,
 			}
 
 			/* Reconnect to the ssh-agent */
+			g_clear_object (&agent_connection);
 			g_clear_error (&error);
-			if (!gkd_ssh_agent_process_connect (self->process, self->cancellable, &error)) {
+			agent_connection = gkd_ssh_agent_process_connect (self->process, self->cancellable, &error);
+			if (!agent_connection) {
 				if (error->code != G_IO_ERROR_CANCELLED)
 					g_message ("couldn't connect to ssh-agent: %s", error->message);
 				g_error_free (error);
@@ -340,6 +348,7 @@ on_run (GThreadedSocketService *service,
 	egg_buffer_uninit (&req);
 	egg_buffer_uninit (&resp);
 
+	g_object_unref (agent_connection);
 	g_object_unref (self);
 
 	return TRUE;
@@ -442,6 +451,7 @@ gkd_ssh_agent_service_lookup_key (GkdSshAgentService *self,
 
 static gboolean
 op_add_identity (GkdSshAgentService *self,
+		 GSocketConnection *connection,
 		 EggBuffer *req,
 		 EggBuffer *resp,
 		 GCancellable *cancellable,
@@ -460,7 +470,7 @@ op_add_identity (GkdSshAgentService *self,
 	else
 		g_message ("got unparseable add identity request for ssh-agent");
 
-	ret = relay_request (self, req, resp, cancellable, error);
+	ret = relay_request (self, connection, req, resp, cancellable, error);
 	if (key) {
 		if (ret)
 			add_key (self, key);
@@ -507,6 +517,7 @@ parse_identities_answer (EggBuffer *resp)
 
 static gboolean
 op_request_identities (GkdSshAgentService *self,
+		       GSocketConnection *connection,
 		       EggBuffer *req,
 		       EggBuffer *resp,
 		       GCancellable *cancellable,
@@ -521,7 +532,7 @@ op_request_identities (GkdSshAgentService *self,
 	GList *l;
 	GkdSshAgentPreload *preload;
 
-	if (!relay_request (self, req, resp, cancellable, error))
+	if (!relay_request (self, connection, req, resp, cancellable, error))
 		return FALSE;
 
 	/* Parse all the keys, and if it fails, just fall through */
@@ -562,6 +573,7 @@ op_request_identities (GkdSshAgentService *self,
 
 static gboolean
 op_sign_request (GkdSshAgentService *self,
+		 GSocketConnection *connection,
 		 EggBuffer *req,
 		 EggBuffer *resp,
 		 GCancellable *cancellable,
@@ -581,11 +593,12 @@ op_sign_request (GkdSshAgentService *self,
 		g_message ("got unparseable sign request for ssh-agent");
 	}
 
-	return relay_request (self, req, resp, cancellable, error);
+	return relay_request (self, connection, req, resp, cancellable, error);
 }
 
 static gboolean
 op_remove_identity (GkdSshAgentService *self,
+		    GSocketConnection *connection,
 		    EggBuffer *req,
 		    EggBuffer *resp,
 		    GCancellable *cancellable,
@@ -605,7 +618,7 @@ op_remove_identity (GkdSshAgentService *self,
 		g_message ("got unparseable remove request for ssh-agent");
 
 	/* Call out ssh-agent anyway to make sure that the key is removed */
-	ret = relay_request (self, req, resp, cancellable, error);
+	ret = relay_request (self, connection, req, resp, cancellable, error);
 	if (key) {
 		if (ret)
 			remove_key (self, key);
@@ -616,6 +629,7 @@ op_remove_identity (GkdSshAgentService *self,
 
 static gboolean
 op_remove_all_identities (GkdSshAgentService *self,
+			  GSocketConnection *connection,
 			  EggBuffer *req,
 			  EggBuffer *resp,
 			  GCancellable *cancellable,
@@ -623,7 +637,7 @@ op_remove_all_identities (GkdSshAgentService *self,
 {
 	gboolean ret;
 
-	ret = relay_request (self, req, resp, cancellable, error);
+	ret = relay_request (self, connection, req, resp, cancellable, error);
 	if (ret)
 		clear_keys (self);
 
