@@ -245,6 +245,7 @@ test_daemon_replace (Test *test,
 	g_assert_cmpint (status, ==, 0);
 }
 
+#ifdef WITH_SSH
 static void
 test_ssh_agent (Test *test,
                         gconstpointer unused)
@@ -265,6 +266,7 @@ test_ssh_agent (Test *test,
 	g_assert (g_file_test (auth_sock, G_FILE_TEST_EXISTS));
 	g_free (auth_sock);
 }
+#endif
 
 int
 main (int argc, char **argv)
@@ -284,8 +286,10 @@ main (int argc, char **argv)
 
 	g_test_add ("/daemon/startup/replace", Test, NULL,
 	            setup, test_daemon_replace, teardown);
+#ifdef WITH_SSH
 	g_test_add ("/daemon/startup/ssh-agent", Test, NULL,
 	            setup, test_ssh_agent, teardown);
+#endif
 
 	return g_test_run ();
 }
