@@ -127,7 +127,7 @@ attributes_new (void)
 static GHashTable*
 entries_new (void)
 {
-	return g_hash_table_new_full (g_str_hash, g_str_equal, NULL, (GDestroyNotify)g_hash_table_unref);
+	return g_hash_table_new_full (g_str_hash, g_str_equal, (GDestroyNotify)g_free, (GDestroyNotify)g_hash_table_unref);
 }
 
 static gboolean
@@ -309,6 +309,7 @@ validate_buffer (EggBuffer *buffer, gsize *offset)
 	gsize n_hash, hash_offset;
 	guint32 length;
 	int algo;
+	gboolean valid;
 
 	g_assert (buffer);
 	g_assert (offset);
@@ -337,10 +338,10 @@ validate_buffer (EggBuffer *buffer, gsize *offset)
 
 	check = g_malloc0 (n_hash);
 	gcry_md_hash_buffer (algo, check, buffer->buf, length);
-	if (memcmp (check, hash, n_hash) != 0)
-		return FALSE;
+	valid = (memcmp (check, hash, n_hash) == 0);
+	g_free (check);
 
-	return TRUE;
+	return valid;
 }
 
 static gboolean
@@ -362,31 +363,24 @@ create_cipher (GkmSecret *login, int calgo, int halgo, const guchar *salt,
 	n_block = gcry_cipher_get_algo_blklen (calgo);
 	g_return_val_if_fail (n_block, FALSE);
 
-	/* Allocate memory for the keys */
-	key = gcry_malloc_secure (n_key);
-	g_return_val_if_fail (key, FALSE);
-	iv = g_malloc0 (n_block);
-
 	password = gkm_secret_get_password (login, &n_password);
 
 	if (!egg_symkey_generate_simple (calgo, halgo, password, n_password,
 	                                 salt, n_salt, iterations, &key, &iv)) {
-		gcry_free (key);
-		g_free (iv);
 		return FALSE;
 	}
 
 	gcry = gcry_cipher_open (cipher, calgo, GCRY_CIPHER_MODE_CBC, 0);
 	if (gcry) {
 		g_warning ("couldn't create cipher context: %s", gcry_strerror (gcry));
-		gcry_free (key);
+		egg_secure_free (key);
 		g_free (iv);
 		return FALSE;
 	}
 
 	gcry = gcry_cipher_setkey (*cipher, key, n_key);
 	g_return_val_if_fail (!gcry, FALSE);
-	gcry_free (key);
+	egg_secure_free (key);
 
 	gcry = gcry_cipher_setiv (*cipher, iv, n_block);
 	g_return_val_if_fail (!gcry, FALSE);
